@@ -43,6 +43,9 @@
 
 Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
 
+const FEEDWRITER_CID = Components.ID("{49bb6593-3aff-4eb3-a068-2712c28bd58e}");
+const FEEDWRITER_CONTRACTID = "@mozilla.org/browser/feeds/result-writer;1";
+
 const XML_NS = "http://www.w3.org/XML/1998/namespace";
 const HTML_NS = "http://www.w3.org/1999/xhtml";
 const XUL_NS = "http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul";
@@ -678,7 +681,7 @@ FeedWriter.prototype = {
    * @returns The display name of the application represented by the file.
    */
   _getFileDisplayName: function getFileDisplayName(file) {
-//@line 695 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/feeds/src/FeedWriter.js"
+//@line 698 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/feeds/src/FeedWriter.js"
     return file.leafName;
   },
 
@@ -740,9 +743,9 @@ FeedWriter.prototype = {
           // XXXben - we need to compare this with the running instance executable
           //          just don't know how to do that via script...
           // XXXmano TBD: can probably add this to nsIShellService
-//@line 762 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/feeds/src/FeedWriter.js"
-          if (fp.file.leafName != "seamonkey-bin") {
 //@line 765 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/feeds/src/FeedWriter.js"
+          if (fp.file.leafName != "seamonkey-bin") {
+//@line 768 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/feeds/src/FeedWriter.js"
             this._initMenuItemWithFile(this._contentSandbox.selectedAppMenuItem,
                                        this._selectedApp);
 
@@ -1360,21 +1363,12 @@ FeedWriter.prototype = {
       });
   },
 
-  // nsIClassInfo
-  getInterfaces: function getInterfaces(countRef) {
-    var interfaces = [Components.interfaces.nsIFeedWriter,
-                       Components.interfaces.nsIClassInfo,
-                       Components.interfaces.nsISupports];
-    countRef.value = interfaces.length;
-    return interfaces;
-  },
-
-  getHelperForLanguage: function getHelperForLanguage(language) null,
-  classID: Components.ID("{49bb6593-3aff-4eb3-a068-2712c28bd58e}"),
-  implementationLanguage: Components.interfaces.nsIProgrammingLanguage.JAVASCRIPT,
-  flags: Components.interfaces.nsIClassInfo.DOM_OBJECT,
+  classID: FEEDWRITER_CID,
+  classInfo: XPCOMUtils.generateCI({classID: FEEDWRITER_CID,
+                                    contractID: FEEDWRITER_CONTRACTID,
+                                    interfaces: [Components.interfaces.nsIFeedWriter],
+                                    flags: Components.interfaces.nsIClassInfo.DOM_OBJECT}),
   QueryInterface: XPCOMUtils.generateQI([Components.interfaces.nsIFeedWriter,
-                                          Components.interfaces.nsIClassInfo,
                                           Components.interfaces.nsIDOMEventListener,
                                           Components.interfaces.nsINavHistoryObserver,
                                           Components.interfaces.nsIObserver])
