@@ -1,4 +1,3 @@
-pref("security.enable_ssl2",             false);
 pref("security.enable_ssl3",             true);
 pref("security.enable_tls",		 true);
 pref("security.enable_tls_session_tickets", true);
@@ -10,12 +9,6 @@ pref("security.ssl.require_safe_negotiation",  false);
 pref("security.ssl.warn_missing_rfc5746",  1);
 pref("security.ssl.enable_false_start", false);
 
-pref("security.ssl2.rc4_128", false);
-pref("security.ssl2.rc2_128", false);
-pref("security.ssl2.des_ede3_192", false);
-pref("security.ssl2.des_64", false);
-pref("security.ssl2.rc4_40", false);
-pref("security.ssl2.rc2_40", false);
 pref("security.ssl3.rsa_rc4_128_md5", true);
 pref("security.ssl3.rsa_rc4_128_sha", true);
 pref("security.ssl3.rsa_fips_des_ede3_sha", true);
@@ -144,16 +137,16 @@ pref("browser.cache.disk.enable",           true);
 pref("browser.cache.disk.smart_size.first_run", true);
 // Does the user want smart-sizing?
 pref("browser.cache.disk.smart_size.enabled", true);
-// Size explicitly set by the user. Used when smart_size.enabled == false
+// Size (in KB) explicitly set by the user. Used when smart_size.enabled == false
 pref("browser.cache.disk.capacity",         256000);
-// User-controllable max-size for entries in disk-cache. Regardless of this
-// setting, no entries bigger than 1/8 of disk-cache will be cached
-pref("browser.cache.disk.max_entry_size",    5120);
+// Max-size (in KB) for entries in disk cache. Set to -1 for no limit.
+// (Note: entries bigger than 1/8 of disk-cache are never cached)
+pref("browser.cache.disk.max_entry_size",    51200);  // 50 MB
 pref("browser.cache.memory.enable",         true);
 // -1 = determine dynamically, 0 = none, n = memory capacity in kilobytes
 //pref("browser.cache.memory.capacity",     -1);
-// User-controllable max-size for entries in mem-cache. Regardless of this
-// setting, no entries bigger than 90% of the mem-cache will be cached
+// Max-size (in KB) for entries in memory cache. Set to -1 for no limit.  
+// (Note: entries bigger than than 90% of the mem-cache are never cached)
 pref("browser.cache.memory.max_entry_size",  5120);
 pref("browser.cache.disk_cache_ssl",        true);
 // 0 = once-per-session, 1 = each-time, 2 = never, 3 = when-appropriate/automatically
@@ -177,6 +170,11 @@ pref("dom.indexedDB.enabled", true);
 // Space to allow indexedDB databases before prompting (in MB).
 pref("dom.indexedDB.warningQuota", 50);
 
+// Whether or not Web Workers are enabled.
+pref("dom.workers.enabled", true);
+// The number of workers per domain allowed to run concurrently.
+pref("dom.workers.maxPerDomain", 20);
+
 // Whether window.performance is enabled
 pref("dom.enable_performance", true);
 
@@ -184,8 +182,6 @@ pref("dom.enable_performance", true);
 // of content viewers to cache based on the amount of available memory.
 pref("browser.sessionhistory.max_total_viewers", -1);
 
-pref("browser.sessionhistory.optimize_eviction", true);
-
 pref("ui.use_native_colors", true);
 pref("ui.click_hold_context_menus", false);
 pref("browser.display.use_document_fonts",  1);  // 0 = never, 1 = quick, 2 = always
@@ -250,13 +246,13 @@ pref("media.cache_size", 512000);
 // Master HTML5 media volume scale.
 pref("media.volume_scale", "1.0");
 
-//@line 177 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
-pref("media.ogg.enabled", true);
 //@line 180 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
-pref("media.wave.enabled", true);
+pref("media.ogg.enabled", true);
 //@line 183 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+pref("media.wave.enabled", true);
+//@line 186 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 pref("media.webm.enabled", true);
-//@line 185 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 188 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 
 // Whether to autostart a media element with an |autoplay| attribute
 pref("media.autoplay.enabled", true);
@@ -266,27 +262,28 @@ pref("media.autoplay.enabled", true);
 pref("gfx.color_management.mode", 2);
 pref("gfx.color_management.display_profile", "");
 pref("gfx.color_management.rendering_intent", 0);
+pref("gfx.color_management.enablev4", false);
 
 pref("gfx.downloadable_fonts.enabled", true);
 pref("gfx.downloadable_fonts.fallback_delay", 3000);
 pref("gfx.downloadable_fonts.sanitize", true);
 
 // see gfx/thebes/gfxUnicodeProperties.h for definitions of script bits
-//@line 204 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 208 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 // use harfbuzz for default (0x01) + arabic (0x02)
 pref("gfx.font_rendering.harfbuzz.scripts", 3);
-//@line 207 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
-
-//@line 212 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 211 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 
 //@line 216 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 
+//@line 220 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
 pref("accessibility.browsewithcaret_shortcut.enabled", true);
 
-//@line 223 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 227 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -303,7 +300,7 @@ pref("accessibility.win32.force_disabled", false);
 // unless this preference was set manually
 pref("ui.scrollToClick", 0);
 
-//@line 243 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 247 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -656,9 +653,9 @@ pref("dom.min_timeout_value", 4);
 pref("dom.min_background_timeout_value", 1000);
 
 // Parsing perf prefs. For now just mimic what the old code did.
-//@line 596 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 600 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 pref("content.sink.pending_event_mode", 0);
-//@line 598 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 602 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 
 // Disable popups from plugins by default
 //   0 = openAllowed
@@ -673,7 +670,7 @@ pref("dom.event.contextmenu.enabled",       true);
 
 pref("javascript.enabled",                  true);
 pref("javascript.options.strict",           false);
-//@line 615 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 619 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 pref("javascript.options.relimit",          true);
 pref("javascript.options.tracejit.content",  true);
 pref("javascript.options.tracejit.chrome",   true);
@@ -681,7 +678,10 @@ pref("javascript.options.methodjit.content", true);
 pref("javascript.options.methodjit.chrome",  true);
 pref("javascript.options.jitprofiling.content", true);
 pref("javascript.options.jitprofiling.chrome",  true);
+pref("javascript.options.pccounts.content", false);
+pref("javascript.options.pccounts.chrome",  false);
 pref("javascript.options.methodjit_always", false);
+pref("javascript.options.typeinference", true);
 // This preference limits the memory usage of javascript.
 // If you want to change these values for your device,
 // please find Bug 417052 comment 17 and Bug 456721
@@ -690,6 +690,7 @@ pref("javascript.options.mem.high_water_mark", 128);
 pref("javascript.options.mem.max", -1);
 pref("javascript.options.mem.gc_per_compartment", true);
 pref("javascript.options.mem.log", false);
+pref("javascript.options.gc_on_memory_pressure", true);
 
 // advanced prefs
 pref("advanced.mailftp",                    false);
@@ -718,7 +719,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 662 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 670 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -769,7 +770,10 @@ pref("network.http.keep-alive.timeout", 115);
 // Note: the socket transport service will clamp the number below 256 if the OS
 // cannot allocate that many FDs, and it also always tries to reserve up to 250
 // file descriptors for things other than sockets.   
+// -- windows using lower limit until bug 692260 resolved
+//@line 724 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 pref("network.http.max-connections", 256);
+//@line 726 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 
 // limit the absolute number of http connections that can be established per
 // host.  if a http proxy server is enabled, then the "server" is the proxy
@@ -872,14 +876,20 @@ pref("network.websocket.timeout.ping.request", 0);
 pref("network.websocket.timeout.ping.response", 10);
 
 // Defines whether or not to try and negotiate the stream-deflate compression
-// extension with the websocket server
-pref("network.websocket.extensions.stream-deflate", true);
+// extension with the websocket server. Stream-Deflate has been removed from
+// the standards track document, but can still be used by servers who opt
+// into it.
+pref("network.websocket.extensions.stream-deflate", false);
 
 // the maximum number of concurrent websocket sessions. By specification there
 // is never more than one handshake oustanding to an individual host at
 // one time.
 pref("network.websocket.max-connections", 200);
 
+// by default scripts loaded from a https:// origin can only open secure
+// (i.e. wss://) websockets.
+pref("network.websocket.allowInsecureFromHTTPS", false);
+
 // </ws>
 
 // Server-Sent Events
@@ -1066,7 +1076,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 1015 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 1034 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 
 // Controls which NTLM authentication implementation we default to. True forces
 // the use of our generic (internal) NTLM authentication implementation vs. any
@@ -1156,12 +1166,65 @@ pref("font.language.group",                 "chrome://global/locale/intl.propert
 pref("intl.uidirection.ar", "rtl");
 pref("intl.uidirection.he", "rtl");
 pref("intl.uidirection.fa", "rtl");
+pref("intl.uidirection.ur", "rtl");
 
 // use en-US hyphenation by default for content tagged with plain lang="en"
 pref("intl.hyphenation-alias.en", "en-us");
 // and for other subtags of en-*, if no specific patterns are available
 pref("intl.hyphenation-alias.en-*", "en-us");
 
+pref("intl.hyphenation-alias.af-*", "af");
+pref("intl.hyphenation-alias.bg-*", "bg");
+pref("intl.hyphenation-alias.ca-*", "ca");
+pref("intl.hyphenation-alias.cy-*", "cy");
+pref("intl.hyphenation-alias.da-*", "da");
+pref("intl.hyphenation-alias.eo-*", "eo");
+pref("intl.hyphenation-alias.es-*", "es");
+pref("intl.hyphenation-alias.et-*", "et");
+pref("intl.hyphenation-alias.fi-*", "fi");
+pref("intl.hyphenation-alias.fr-*", "fr");
+pref("intl.hyphenation-alias.gl-*", "gl");
+pref("intl.hyphenation-alias.hr-*", "hr");
+pref("intl.hyphenation-alias.hsb-*", "hsb");
+pref("intl.hyphenation-alias.hu-*", "hu");
+pref("intl.hyphenation-alias.ia-*", "ia");
+pref("intl.hyphenation-alias.is-*", "is");
+pref("intl.hyphenation-alias.it-*", "it");
+pref("intl.hyphenation-alias.kmr-*", "kmr");
+pref("intl.hyphenation-alias.la-*", "la");
+pref("intl.hyphenation-alias.lt-*", "lt");
+pref("intl.hyphenation-alias.mn-*", "mn");
+pref("intl.hyphenation-alias.nl-*", "nl");
+pref("intl.hyphenation-alias.pt-*", "pt");
+pref("intl.hyphenation-alias.ru-*", "ru");
+pref("intl.hyphenation-alias.sl-*", "sl");
+pref("intl.hyphenation-alias.sv-*", "sv");
+pref("intl.hyphenation-alias.tr-*", "tr");
+pref("intl.hyphenation-alias.uk-*", "uk");
+
+// use reformed (1996) German patterns by default unless specifically tagged as de-1901
+// (these prefs may soon be obsoleted by better BCP47-based tag matching, but for now...)
+pref("intl.hyphenation-alias.de", "de-1996");
+pref("intl.hyphenation-alias.de-*", "de-1996");
+pref("intl.hyphenation-alias.de-DE-1901", "de-1901");
+pref("intl.hyphenation-alias.de-CH-*", "de-CH");
+
+// patterns from TeX are tagged as "sh" (Serbo-Croatian) macrolanguage;
+// alias "sr" (Serbian) and "bs" (Bosnian) to those patterns
+// (Croatian has its own separate patterns).
+pref("intl.hyphenation-alias.sr", "sh");
+pref("intl.hyphenation-alias.bs", "sh");
+pref("intl.hyphenation-alias.sh-*", "sh");
+pref("intl.hyphenation-alias.sr-*", "sh");
+pref("intl.hyphenation-alias.bs-*", "sh");
+
+// Norwegian has two forms, Bokmål and Nynorsk, with "no" as a macrolanguage encompassing both.
+// For "no", we'll alias to "nb" (Bokmål) as that is the more widely used written form.
+pref("intl.hyphenation-alias.no", "nb");
+pref("intl.hyphenation-alias.no-*", "nb");
+pref("intl.hyphenation-alias.nb-*", "nb");
+pref("intl.hyphenation-alias.nn-*", "nn");
+
 pref("font.mathfont-family", "STIXNonUnicode, STIXSizeOneSym, STIXSize1, STIXGeneral, Asana Math, Standard Symbols L, DejaVu Sans, Cambria Math");
 
 // Some CJK fonts have bad underline offset, their CJK character glyphs are overlapped (or adjoined)  to its underline.
@@ -1451,25 +1514,32 @@ pref("editor.positioning.offset",            0);
 pref("dom.max_chrome_script_run_time", 20);
 pref("dom.max_script_run_time", 10);
 
-//@line 1400 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 1472 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 // How long a plugin is allowed to process a synchronous IPC message
 // before we consider it "hung".
 pref("dom.ipc.plugins.timeoutSecs", 45);
+// How long a plugin process will wait for a response from the parent
+// to a synchronous request before terminating itself. After this
+// point the child assumes the parent is hung.
+// Disabled in release builds for Aurora and up
+pref("dom.ipc.plugins.parentTimeoutSecs", 0);
 // How long a plugin launch is allowed to take before
 // we consider it failed.
 pref("dom.ipc.plugins.processLaunchTimeoutSecs", 45);
-//@line 1411 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 1489 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 
 // Disable oopp for standard java. They run their own process isolation (which
 // conflicts with our implementation, at least on Windows).
 pref("dom.ipc.plugins.java.enabled", false);
 
-//@line 1419 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 1497 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 // Linux plugins using Xt instead of Xembed don't work out-of-process yet.
 pref("dom.ipc.plugins.enabled.libvlcplugin.so", false);
 pref("dom.ipc.plugins.enabled.nppdf.so", false);
 pref("dom.ipc.plugins.enabled.602plugin.so", false);
-//@line 1426 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 1504 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+
+pref("dom.ipc.processCount", 1);
 
 pref("svg.smil.enabled", true);
 
@@ -1506,15 +1576,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1928 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2008 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2361 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2441 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2561 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2641 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2830 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2910 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2834 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2914 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.protocol-handler.warn-external.file", false);
 pref("browser.drag_out_of_frame_style", 1);
@@ -1782,11 +1852,11 @@ pref("ui.panel.default_level_parent", true);
 
 pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 
-//@line 3105 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 3185 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 3125 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 3205 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 3133 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 3213 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1835,7 +1905,7 @@ pref("image.mem.discardable", true);
 
 // Prevents images from automatically being decoded on load, instead allowing
 // them to be decoded on demand when they are drawn.
-pref("image.mem.decodeondraw", false);
+pref("image.mem.decodeondraw", true);
 
 // Minimum timeout for image discarding (in milliseconds). The actual time in
 // which an image must inactive for it to be discarded will vary between this
@@ -1847,10 +1917,10 @@ pref("image.mem.decodeondraw", false);
 pref("image.mem.min_discard_timeout_ms", 10000);
 
 // Chunk size for calls to the image decoders
-pref("image.mem.decode_bytes_at_a_time", 200000);
+pref("image.mem.decode_bytes_at_a_time", 4096);
 
 // The longest time we can spend in an iteration of an async decode
-pref("image.mem.max_ms_before_yield", 400);
+pref("image.mem.max_ms_before_yield", 5);
 
 // The maximum source data size for which we auto sync decode
 pref("image.mem.max_bytes_for_sync_decode", 150000);
@@ -1864,15 +1934,19 @@ pref("webgl.osmesalib", "");
 pref("webgl.verbose", false);
 pref("webgl.prefer-native-gl", false);
 
-//@line 3214 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+//@line 3294 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 
 // Whether to disable acceleration for all widgets.
+//@line 3299 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 pref("layers.acceleration.disabled", false);
+//@line 3301 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 
 // Whether to force acceleration on, ignoring blacklists.
 pref("layers.acceleration.force-enabled", false);
 
-//@line 3231 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
+pref("layers.acceleration.draw-fps", false);
+
+//@line 3321 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
@@ -1907,3 +1981,21 @@ pref("network.buffer.cache.size",  32768);
 
 // Desktop Notification
 pref("notification.feature.enabled", false);
+
+// Alert sliding effect
+pref("alerts.slideIncrement", 1);
+pref("alerts.slideIncrementTime", 10);
+pref("alerts.totalOpenTime", 4000);
+pref("alerts.disableSlidingEffect", false);
+
+// DOM full-screen API.
+pref("full-screen-api.enabled", false);
+pref("full-screen-api.allow-trusted-requests-only", true);
+pref("full-screen-api.key-input-restricted", true);
+
+// Time limit, in milliseconds, for nsEventStateManager::IsHandlingUserInput().
+// Used to detect long running handlers of user-generated events.
+pref("dom.event.handling-user-input-time-limit", 1000);
+ 
+//3D Transforms
+pref("layout.3d-transforms.enabled", false);
