@@ -284,6 +284,11 @@ pref("browser.tabs.tabClipWidth", 140);
 // 3  at the end of the tabstrip
 pref("browser.tabs.closeButtons", 3);
 
+// Mouse wheel action when over the tab bar:
+// false  The mouse wheel scrolls the whole tab bar like Firefox (default).
+// true   The mouse wheel advances the selected tab.
+pref("browser.tabs.mouseScrollAdvancesTab", false);
+
 // lets new tab/window load something different than first window
 // -1 - use navigator startup preference
 //  0 - loads blank page
@@ -328,6 +333,9 @@ pref("browser.zoom.siteSpecific", true);
 // once they come to the foreground (i.e. get activated).
 pref("browser.zoom.updateBackgroundTabs", true);
 
+// Zoom levels for View > Zoom and Ctrl +/- keyboard shortcuts
+pref("toolkit.zoomManager.zoomValues", "0.5,0.67,0.8,0.9,1,1.1,1.2,1.33,1.5,1.7,2,2.4");
+
 pref("javascript.options.showInConsole",    true);
 
 pref("offline.startup_state",            0);
@@ -357,13 +365,13 @@ pref("accessibility.blockautorefresh", false);
 // Use the findbar for type ahead find, instead of the XPFE implementation
 pref("accessibility.typeaheadfind.usefindbar", true);
 pref("accessibility.typeaheadfind.flashBar", 0);
-//@line 363 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/browser/browser-prefs.js"
+//@line 371 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/browser/browser-prefs.js"
 
-//@line 367 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/browser/browser-prefs.js"
+//@line 375 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/browser/browser-prefs.js"
 pref("browser.preferences.instantApply", true);
-//@line 372 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/browser/browser-prefs.js"
+//@line 380 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/browser/browser-prefs.js"
 pref("browser.preferences.animateFadeIn", false);
-//@line 374 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/browser/browser-prefs.js"
+//@line 382 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/browser/browser-prefs.js"
 
 pref("browser.download.show_plugins_in_list", true);
 pref("browser.download.hide_plugins_without_extensions", true);
@@ -572,6 +580,7 @@ pref("extensions.webservice.discoverURL", "https://services.addons.mozilla.org/%
 
 // getMoreThemes is used by our UI under our switch theme menu
 pref("extensions.getMoreThemesURL", "chrome://branding/locale/brand.properties");
+pref("extensions.getPersonasURL", "chrome://branding/locale/brand.properties");
 pref("extensions.dss.enabled", false);          // Dynamic Skin Switching
 pref("extensions.dss.switchPending", false);    // Non-dynamic switch pending after next
                                                 // restart.
@@ -593,7 +602,7 @@ pref("custtoolbar.personal_toolbar_folder", "");
 // Use a popup window for the customize toolbar UI
 pref("toolbar.customization.usesheet", false);
 
-//@line 611 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/browser/browser-prefs.js"
+//@line 620 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/browser/browser-prefs.js"
 
 pref("sidebar.customize.all_panels.url", "http://sidebar-rdf.netscape.com/%LOCALE%/sidebar-rdf/%SIDEBAR_VERSION%/all-panels.rdf");
 pref("sidebar.customize.directory.url", "http://dmoz.org/Netscape/Sidebar/");
@@ -663,9 +672,9 @@ pref("dom.event.contextmenu.enabled",  true);
 
 // The default for this pref reflects whether the build is capable of IPC.
 // (Turning it on in a no-IPC build will have no effect.)
-//@line 698 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/browser/browser-prefs.js"
+//@line 707 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/browser/browser-prefs.js"
 pref("dom.ipc.plugins.enabled", true);
-//@line 700 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/browser/browser-prefs.js"
+//@line 709 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/browser/browser-prefs.js"
 
 // plugin finder service url
 pref("pfs.datasource.url", "https://pfs.mozilla.org/plugins/PluginFinderService.php?mimetype=%PLUGIN_MIMETYPE%&appID=%APP_ID%&appVersion=%APP_VERSION%&clientOS=%CLIENT_OS%&chromeLocale=%CHROME_LOCALE%");
@@ -675,16 +684,24 @@ pref("plugins.hide_infobar_for_outdated_plugin", false);
 pref("plugins.hide_infobar_for_carbon_failure_plugin", false);
 pref("plugins.hide_infobar_for_missing_plugin", false);
 
-//@line 710 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/browser/browser-prefs.js"
+//@line 721 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/browser/browser-prefs.js"
+
+//@line 723 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/browser/browser-prefs.js"
 // Restore the spinner that was removed in bug 481359
 pref("ui.use_activity_cursor", true);
-//@line 713 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/browser/browser-prefs.js"
-
-//@line 728 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/browser/browser-prefs.js"
+//@line 726 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/browser/browser-prefs.js"
 
 //@line 731 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/browser/browser-prefs.js"
+
+//@line 734 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/browser/browser-prefs.js"
 // For the download dialog
 pref("browser.download.progressDnldDialog.enable_launch_reveal_buttons", false);
+
+// Mouse wheel action when over the tab bar:
+// false  The mouse wheel scrolls the whole tab bar like Firefox.
+// true   The mouse wheel advances the selected tab.
+pref("browser.tabs.mouseScrollAdvancesTab", true);
+
 pref("browser.urlbar.clickSelectsAll", false);
 
 // 0 goes back
@@ -695,7 +712,7 @@ pref("browser.backspace_action", 2);
 pref("general.autoScroll", false);
 
 pref("layout.word_select.stop_at_punctuation", false);
-//@line 745 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/browser/browser-prefs.js"
+//@line 754 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/browser/browser-prefs.js"
 
 // The breakpad report server to link to in about:crashes
 pref("breakpad.reportURL", "http://crash-stats.mozilla.com/report/index/");
@@ -709,7 +726,7 @@ pref("browser.geolocation.warning.infoURL", "http://www.seamonkey-project.org/do
 pref("browser.rights.version", 1);
 pref("browser.rights.1.shown", false);
 
-//@line 765 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/browser/browser-prefs.js"
+//@line 774 "/builds/slave/rel-comm-rel-lnx-bld/build/suite/browser/browser-prefs.js"
 
 // The sync engines to use.
 pref("services.sync.registerEngines", "Bookmarks,Form,History,Password,Prefs,Tab");
