@@ -525,7 +525,8 @@ pref("mail.send_struct", false);   // HTML->HTML *bold* etc. during Send; ditto
 pref("mailnews.display.date_senders_timezone", false);
 // For the next 4 prefs, see <http://www.bucksch.org/1/projects/mozilla/108153>
 pref("mailnews.display.prefer_plaintext", false);  // Ignore HTML parts in multipart/alternative
-pref("mailnews.display.html_as", 0);  // How to display HTML parts. 0 = Render the sender's HTML; 1 = HTML->TXT->HTML; 2 = Show HTML source; 3 = Sanitize HTML
+pref("mailnews.display.html_as", 0);  // How to display HTML/MIME parts. 0 = Render the sender's HTML; 1 = HTML->TXT->HTML; 2 = Show HTML source; 3 = Sanitize HTML; 4 = Show all body parts
+pref("mailnews.display.show_all_body_parts_menu", false); // Whether the View > Message body as > All body parts menu item is available
 pref("mailnews.display.html_sanitizer.allowed_tags", "html head title body p br div(lang,title) h1 h2 h3 h4 h5 h6 ul(type,compact) ol(type,compact,start) li(type,value) dl dt dd blockquote(type,cite) pre noscript noframes strong em sub sup span(lang,title) acronym(title) abbr(title) del(title,cite,datetime) ins(title,cite,datetime) q(cite) a(href,name,title) img(alt,title,longdesc,src) base(href) area(alt) applet(alt) object(alt) var samp dfn address kbd code cite s strike tt b i table(align) caption tr(align,valign) td(rowspan,colspan,align,valign) th(rowspan,colspan,align,valign) wbr");
 pref("mailnews.display.disallow_mime_handlers", 0);  /* Let only a few classes process incoming data. This protects from bugs (e.g. buffer overflows) and from security loopholes (e.g. allowing unchecked HTML in some obscure classes, although the user has html_as > 0).
 This option is mainly for the UI of html_as.
@@ -631,10 +632,10 @@ pref("mail.biff.animate_dock_icon", false);
 // add jitter to biff interval
 pref("mail.biff.add_interval_jitter", true);
 
-//@line 635 "/builds/slave/rel-comm-rel-lnx-bld/build/mailnews/mailnews.js"
+//@line 636 "/builds/slave/rel-comm-rel-lnx-bld/build/mailnews/mailnews.js"
 // if true, check for new mail even when opening non-mail windows
 pref("mail.biff.on_new_window", true);
-//@line 638 "/builds/slave/rel-comm-rel-lnx-bld/build/mailnews/mailnews.js"
+//@line 639 "/builds/slave/rel-comm-rel-lnx-bld/build/mailnews/mailnews.js"
 
 // If true, the number used in the Mac OS X dock notification will be the
 // the number of "new" messages, as per the classic Thunderbird definition.
@@ -661,9 +662,9 @@ pref("mailnews.ui.junk.manualMarkAsJunkMarksRead", true);
 pref("mail.ui.folderpane.version", 1);
 
 // for manual upgrades of certain UI features.
-//@line 665 "/builds/slave/rel-comm-rel-lnx-bld/build/mailnews/mailnews.js"
+//@line 666 "/builds/slave/rel-comm-rel-lnx-bld/build/mailnews/mailnews.js"
 pref("mailnews.ui.threadpane.version", 5);
-//@line 670 "/builds/slave/rel-comm-rel-lnx-bld/build/mailnews/mailnews.js"
+//@line 671 "/builds/slave/rel-comm-rel-lnx-bld/build/mailnews/mailnews.js"
 // for manual upgrades of certain UI features.
 // 1 -> 2 is for the ab results pane tree landing
 // to hide the non default columns in the addressbook dialog
@@ -748,16 +749,16 @@ pref("mailnews.import.text.skipfirstrecord", true);
 // automatically scale attached images that are displayed inline
 pref("mail.enable_automatic_image_resizing", true);
 
-//@line 768 "/builds/slave/rel-comm-rel-lnx-bld/build/mailnews/mailnews.js"
+//@line 769 "/builds/slave/rel-comm-rel-lnx-bld/build/mailnews/mailnews.js"
 
 // gtk2 (*nix) lacks transparent/translucent drag support (bug 376238), so we
 // want to disable it so people can see where they are dragging things.
 // (Stock gtk drag icons will be used instead.)
-//@line 773 "/builds/slave/rel-comm-rel-lnx-bld/build/mailnews/mailnews.js"
+//@line 774 "/builds/slave/rel-comm-rel-lnx-bld/build/mailnews/mailnews.js"
 pref("nglayout.enable_drag_images", false);
-//@line 775 "/builds/slave/rel-comm-rel-lnx-bld/build/mailnews/mailnews.js"
+//@line 776 "/builds/slave/rel-comm-rel-lnx-bld/build/mailnews/mailnews.js"
 
-//@line 779 "/builds/slave/rel-comm-rel-lnx-bld/build/mailnews/mailnews.js"
+//@line 780 "/builds/slave/rel-comm-rel-lnx-bld/build/mailnews/mailnews.js"
 
 // For the Empty Junk/Trash confirmation dialogs.
 pref("mailnews.emptyJunk.dontAskAgain", false);
