@@ -30,13 +30,14 @@ const PREFS_WHITELIST = [
   "general.useragent.",
   "gfx.",
   "html5.",
-  "mozilla.widget.render-mode",
   "layers.",
   "javascript.",
   "keyword.",
   "layout.css.dpi",
   "network.",
   "places.",
+  "plugin.",
+  "plugins.",
   "print.",
   "privacy.",
   "security.",
@@ -208,7 +209,7 @@ function populateGraphicsSection() {
     pushInfoRow(trGraphics, "driverVersion", gfxInfo.adapterDriverVersion);
     pushInfoRow(trGraphics, "driverDate", gfxInfo.adapterDriverDate);
 
-//@line 275 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/toolkit/content/aboutSupport.js"
+//@line 285 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/toolkit/content/aboutSupport.js"
 
     var webglrenderer;
     var webglenabled;
@@ -219,9 +220,9 @@ function populateGraphicsSection() {
       webglrenderer = false;
       webglenabled = false;
     }
-//@line 293 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/toolkit/content/aboutSupport.js"
+//@line 303 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/toolkit/content/aboutSupport.js"
     var webglfeature = gfxInfo.FEATURE_WEBGL_OPENGL;
-//@line 295 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/toolkit/content/aboutSupport.js"
+//@line 305 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/toolkit/content/aboutSupport.js"
     pushFeatureInfoRow(trGraphics, "webglRenderer", webglfeature, webglenabled, webglrenderer);
 
     appendChildren(graphics_tbody, trGraphics);
@@ -256,9 +257,9 @@ function populateGraphicsSection() {
   if (acceleratedWindows) {
     msg += " " + mgrType;
   } else {
-//@line 332 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/toolkit/content/aboutSupport.js"
+//@line 342 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/toolkit/content/aboutSupport.js"
     var feature = gfxInfo.FEATURE_OPENGL_LAYERS;
-//@line 334 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/toolkit/content/aboutSupport.js"
+//@line 344 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/toolkit/content/aboutSupport.js"
     var errMsg = errorMessageForFeature(feature);
     if (errMsg)
       msg += ". " + errMsg;
@@ -390,7 +391,7 @@ function createTextForElement(elem) {
   text = text.replace(/\n\n\n+/g, "\n\n");
 
   // Actual CR/LF pairs are needed for some Windows text editors.
-//@line 468 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/toolkit/content/aboutSupport.js"
+//@line 478 "/builds/slave/rel-comm-rel-lnx-bld/build/mozilla/toolkit/content/aboutSupport.js"
 
   return text;
 }
