@@ -12,7 +12,8 @@ var gSlideIncrement = 1;
 var gSlideTime = 10;
 var gOpenTime = 3000; // total time the alert should stay up once we are done animating.
 var gOrigin = 0; // Default value: alert from bottom right, sliding in vertically.
-
+var gDisableSlideEffect = false;
+ 
 var gAlertListener = null;
 var gAlertTextClickable = false;
 var gAlertCookie = "";
@@ -56,20 +57,14 @@ function prefillAlertInfo()
 
 function onAlertLoad()
 {
-  // Read out our initial settings from prefs.
-  try 
-  {
-    var prefService = Components.classes["@mozilla.org/preferences-service;1"].getService();
-    prefService = prefService.QueryInterface(Components.interfaces.nsIPrefService);
-    var prefBranch = prefService.getBranch(null);
-    gSlideIncrement = prefBranch.getIntPref("alerts.slideIncrement");
-    gSlideTime = prefBranch.getIntPref("alerts.slideIncrementTime");
-    gOpenTime = prefBranch.getIntPref("alerts.totalOpenTime");
-  }
-  catch (ex)
-  {
-  }
-
+  var prefService = Components.classes["@mozilla.org/preferences-service;1"].getService();
+  prefService = prefService.QueryInterface(Components.interfaces.nsIPrefService);
+  var prefBranch = prefService.getBranch(null);
+  gSlideIncrement = prefBranch.getIntPref("alerts.slideIncrement");
+  gSlideTime = prefBranch.getIntPref("alerts.slideIncrementTime");
+  gOpenTime = prefBranch.getIntPref("alerts.totalOpenTime");
+  gDisableSlideEffect = prefBranch.getBoolPref("alerts.disableSlidingEffect");
+ 
   // Make sure that the contents are fixed at the window edge facing the
   // screen's center so that the window looks like "sliding in" and not
   // like "unfolding". The default packing of "start" only works for
@@ -91,14 +86,6 @@ function onAlertLoad()
   var alertBox = document.getElementById("alertBox");
   alertBox.orient = (gOrigin & NS_ALERT_HORIZONTAL) ? "vertical" : "horizontal";
 
-  // The above doesn't cause the labels in alertTextBox to reflow,
-  // see bug 311557. As the theme's -moz-box-align css rule gets ignored,
-  // we work around the bug by setting the align property.
-  if (gOrigin & NS_ALERT_HORIZONTAL)
-  {
-    document.getElementById("alertTextBox").align = "center";
-  }
-
   sizeToContent();
 
   // Work around a bug where sizeToContent() leaves a border outside of the content
@@ -142,6 +129,9 @@ function animate(step)
 {
   gCurrentSize += step;
 
+  if (gFinalSize < gCurrentSize)
+    gCurrentSize = gFinalSize;
+
   if (gOrigin & NS_ALERT_HORIZONTAL)
   {
     if (!(gOrigin & NS_ALERT_LEFT))
@@ -160,7 +150,10 @@ function animateAlert()
 {
   if (gCurrentSize < gFinalSize)
   {
-    animate(gSlideIncrement);
+    if (gDisableSlideEffect)
+      animate(gFinalSize); // We don't begin on zero.
+    else
+      animate(gSlideIncrement);
     setTimeout(animateAlert, gSlideTime);
   }
   else
@@ -169,7 +162,7 @@ function animateAlert()
 
 function animateCloseAlert()
 {
-  if (gCurrentSize > 1)
+  if (gCurrentSize > 1 && !gDisableSlideEffect)
   {
     animate(-gSlideIncrement);
     setTimeout(animateCloseAlert, gSlideTime);
